@@ -26,9 +26,9 @@ class PreferencesDialog : public QDialog {
 
 	protected:
 
-		QCheckBox *decimalCommaBox, *ignoreCommaBox, *ignoreDotBox, *statusBox;
+		QCheckBox *decimalCommaBox, *ignoreCommaBox, *ignoreDotBox, *statusBox, *ignoreLocaleBox;
 		QSpinBox *exratesSpin, *statusDelayWidget;
-		QComboBox *styleCombo, *parseCombo, *tcCombo;
+		QComboBox *styleCombo, *parseCombo, *tcCombo, *langCombo;
 
 		void closeEvent(QCloseEvent*) override;
 
@@ -41,6 +41,7 @@ class PreferencesDialog : public QDialog {
 		void binTwosToggled(bool);
 		void hexTwosToggled(bool);
 		void lowerCaseToggled(bool);
+		void duodecimalSymbolsToggled(bool);
 		void multiplicationDotToggled(bool);
 		void divisionSlashToggled(bool);
 		void spellOutToggled(bool);
@@ -83,6 +84,7 @@ class PreferencesDialog : public QDialog {
 		void appFontToggled(bool);
 		void darkModeToggled(bool);
 		void styleChanged(int);
+		void langChanged(int);
 		void factorizeToggled(bool);
 		void rpnKeysToggled(bool);
 		void replaceExpressionChanged(int);
